pub struct BulkFilter {
pub frame: Frame,
pub from_wallet: Option<WalletId>,
}Expand description
Filter narrowing which pending outbound transfers a bulk plan selects.
Fields
frame: Framefrom_wallet: Option<WalletId>Trait Implementations
Sourceimpl Clone for BulkFilter
impl Clone for BulkFilter
Sourcefn clone(&self) -> BulkFilter
fn clone(&self) -> BulkFilter
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkFilter
impl Debug for BulkFilter
impl Eq for BulkFilter
Sourceimpl PartialEq for BulkFilter
impl PartialEq for BulkFilter
Sourcefn eq(&self, other: &BulkFilter) -> bool
fn eq(&self, other: &BulkFilter) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BulkFilter