pub fn j1() -> JourneyFixtureExpand description
The nine journey fixtures, keyed by the same corpus filenames the examples journeys use.
pub fn j1() -> JourneyFixtureThe nine journey fixtures, keyed by the same corpus filenames the examples journeys use.